@@ -4,7 +4,7 @@ import unittest
 from hein_control.action import Action, EvalAction, TrackedDecision, ConfiguredAction, ConfiguredDecision, \
     ThreadedTrackedAction, TrackedAction, ConfiguredActionList, ConfigurableInstance
 from hein_control.action.operators import execute_sequence_actions, run_automation, decision
-from hein_control.mixin import Configuration, Status
+from hein_control.mixin import Configuration, Status, is_jsonable
 
 logger = logging.getLogger(__name__)
 
@@ -48,6 +48,11 @@ def passthrough(*args, **kwargs):
     return args, kwargs
 
 
+def as_dict_serializable(action) -> bool:
+    """verifies that the as_dict representation is serializable"""
+    return is_jsonable(action.as_dict())
+
+
 class TestActions(unittest.TestCase):
     def setUp(self) -> None:
         # register all actions
@@ -219,6 +224,12 @@ class TestConfiguredAction(unittest.TestCase):
             ('this_should_be_undefined'),
         )
 
+    def test_serializable(self):
+        """tests that the registered actions are serializable"""
+        conf_action_apple = ConfiguredAction(passthrough,
+                                             configuration_name='apple')
+        self.assertTrue(as_dict_serializable(conf_action_apple))
+
     def test_configured_action(self):
         """test all the methods of the configured action class"""
         args = ('metal', 'squirrel')
@@ -338,7 +349,7 @@ class TestEvalAction(unittest.TestCase):
 class TestDecisions(unittest.TestCase):
     @staticmethod
     def print_false():
-        print('this wont be printed')
+        print('this should not be printed')
 
     @staticmethod
     def print_true():
@@ -350,12 +361,10 @@ class TestDecisions(unittest.TestCase):
 
     @staticmethod
     def return_true(string, **kwargs) -> bool:
-        print(f'{string} - True')
         return True
 
     @staticmethod
     def return_false(string, **kwargs) -> bool:
-        print(f'{string} - False')
         return False
 
     def test_decisionaction(self):
@@ -385,7 +394,9 @@ class TestDecisions(unittest.TestCase):
         )
         # create the decision action and execute it
         decision_action = TrackedDecision(configuration=config_decision)
+        self.assertTrue(as_dict_serializable(decision_action))
         decision_action()
+        self.assertTrue(as_dict_serializable(decision_action))
         decision_next_action = decision_action.next_action
         self.assertEqual(decision_next_action, true_next)
         # change the next action of true action, make a new decision action and make sure the new next action gets
@@ -409,8 +420,10 @@ class TestTrackedAction(unittest.TestCase):
         tracked_action = TrackedAction(
             one_second
         )
+        self.assertTrue(as_dict_serializable(tracked_action))
         start_time = time.time()
         tracked_action()
+        self.assertTrue(as_dict_serializable(tracked_action))
         end_time = time.time()
         self.assertAlmostEqual(
             start_time,
